@@ -12,7 +12,6 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 
 **/
 
-
 #ifndef __BASE_H__
 #define __BASE_H__
 
@@ -21,11 +20,11 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 //
 #include <ProcessorBind.h>
 
-#if defined(_MSC_EXTENSIONS)
+#if defined (_MSC_EXTENSIONS)
 //
 // Disable warning when last field of data structure is a zero sized array.
 //
-#pragma warning ( disable : 4200 )
+  #pragma warning ( disable : 4200 )
 #endif
 
 //
@@ -33,20 +32,20 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 //  if the /OPT:REF linker option is used. We defined a macro as this is a
 //  a non standard extension
 //
-#if defined(_MSC_VER) && _MSC_VER < 1800 && !defined (MDE_CPU_EBC)
-  ///
-  /// Remove global variable from the linked image if there are no references to
-  /// it after all compiler and linker optimizations have been performed.
-  ///
-  ///
-  #define GLOBAL_REMOVE_IF_UNREFERENCED __declspec(selectany)
+#if defined (_MSC_VER) && _MSC_VER < 1800 && !defined (MDE_CPU_EBC)
+///
+/// Remove global variable from the linked image if there are no references to
+/// it after all compiler and linker optimizations have been performed.
+///
+///
+#define GLOBAL_REMOVE_IF_UNREFERENCED  __declspec(selectany)
 #else
-  ///
-  /// Remove the global variable from the linked image if there are no references
-  ///  to it after all compiler and linker optimizations have been performed.
-  ///
-  ///
-  #define GLOBAL_REMOVE_IF_UNREFERENCED
+///
+/// Remove the global variable from the linked image if there are no references
+///  to it after all compiler and linker optimizations have been performed.
+///
+///
+#define GLOBAL_REMOVE_IF_UNREFERENCED
 #endif
 
 //
@@ -55,27 +54,27 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 //
 #ifndef UNREACHABLE
   #ifdef __GNUC__
-    ///
-    /// Signal compilers and analyzers that this call is not reachable.  It is
-    /// up to the compiler to remove any code past that point.
-    ///
-    #define UNREACHABLE()  __builtin_unreachable ()
+///
+/// Signal compilers and analyzers that this call is not reachable.  It is
+/// up to the compiler to remove any code past that point.
+///
+#define UNREACHABLE()  __builtin_unreachable ()
   #elif defined (__has_feature)
     #if __has_builtin (__builtin_unreachable)
-      ///
-      /// Signal compilers and analyzers that this call is not reachable.  It is
-      /// up to the compiler to remove any code past that point.
-      ///
-      #define UNREACHABLE()  __builtin_unreachable ()
+///
+/// Signal compilers and analyzers that this call is not reachable.  It is
+/// up to the compiler to remove any code past that point.
+///
+#define UNREACHABLE()  __builtin_unreachable ()
     #endif
   #endif
 
   #ifndef UNREACHABLE
-    ///
-    /// Signal compilers and analyzers that this call is not reachable.  It is
-    /// up to the compiler to remove any code past that point.
-    ///
-    #define UNREACHABLE()
+///
+/// Signal compilers and analyzers that this call is not reachable.  It is
+/// up to the compiler to remove any code past that point.
+///
+#define UNREACHABLE()
   #endif
 #endif
 
@@ -86,26 +85,26 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 //
 #ifndef NORETURN
   #if defined (__GNUC__) || defined (__clang__)
-    ///
-    /// Signal compilers and analyzers that the function cannot return.
-    /// It is up to the compiler to remove any code past a call to functions
-    /// flagged with this attribute.
-    ///
-    #define NORETURN  __attribute__((noreturn))
-  #elif defined(_MSC_EXTENSIONS) && !defined(MDE_CPU_EBC)
-    ///
-    /// Signal compilers and analyzers that the function cannot return.
-    /// It is up to the compiler to remove any code past a call to functions
-    /// flagged with this attribute.
-    ///
-    #define NORETURN  __declspec(noreturn)
+///
+/// Signal compilers and analyzers that the function cannot return.
+/// It is up to the compiler to remove any code past a call to functions
+/// flagged with this attribute.
+///
+#define NORETURN  __attribute__((noreturn))
+  #elif defined (_MSC_EXTENSIONS) && !defined (MDE_CPU_EBC)
+///
+/// Signal compilers and analyzers that the function cannot return.
+/// It is up to the compiler to remove any code past a call to functions
+/// flagged with this attribute.
+///
+#define NORETURN  __declspec(noreturn)
   #else
-    ///
-    /// Signal compilers and analyzers that the function cannot return.
-    /// It is up to the compiler to remove any code past a call to functions
-    /// flagged with this attribute.
-    ///
-    #define NORETURN
+///
+/// Signal compilers and analyzers that the function cannot return.
+/// It is up to the compiler to remove any code past a call to functions
+/// flagged with this attribute.
+///
+#define NORETURN
   #endif
 #endif
 
@@ -116,20 +115,20 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #ifndef ANALYZER_UNREACHABLE
   #ifdef __clang_analyzer__
     #if __has_builtin (__builtin_unreachable)
-      ///
-      /// Signal the analyzer that this call is not reachable.
-      /// This excludes compilers.
-      ///
-      #define ANALYZER_UNREACHABLE()  __builtin_unreachable ()
+///
+/// Signal the analyzer that this call is not reachable.
+/// This excludes compilers.
+///
+#define ANALYZER_UNREACHABLE()  __builtin_unreachable ()
     #endif
   #endif
 
   #ifndef ANALYZER_UNREACHABLE
-    ///
-    /// Signal the analyzer that this call is not reachable.
-    /// This excludes compilers.
-    ///
-    #define ANALYZER_UNREACHABLE()
+///
+/// Signal the analyzer that this call is not reachable.
+/// This excludes compilers.
+///
+#define ANALYZER_UNREACHABLE()
   #endif
 #endif
 
@@ -142,20 +141,20 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 #ifndef ANALYZER_NORETURN
   #ifdef __has_feature
     #if __has_feature (attribute_analyzer_noreturn)
-      ///
-      /// Signal analyzers that the function cannot return.
-      /// This excludes compilers.
-      ///
-      #define ANALYZER_NORETURN  __attribute__((analyzer_noreturn))
+///
+/// Signal analyzers that the function cannot return.
+/// This excludes compilers.
+///
+#define ANALYZER_NORETURN  __attribute__((analyzer_noreturn))
     #endif
   #endif
 
   #ifndef ANALYZER_NORETURN
-    ///
-    /// Signal the analyzer that the function cannot return.
-    /// This excludes compilers.
-    ///
-    #define ANALYZER_NORETURN
+///
+/// Signal the analyzer that the function cannot return.
+/// This excludes compilers.
+///
+#define ANALYZER_NORETURN
   #endif
 #endif
 
@@ -165,17 +164,17 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 ///
 #ifndef RETURNS_TWICE
   #if defined (__GNUC__) || defined (__clang__)
-    ///
-    /// Tell the code optimizer that the function will return twice.
-    /// This prevents wrong optimizations which can cause bugs.
-    ///
-    #define RETURNS_TWICE  __attribute__((returns_twice))
+///
+/// Tell the code optimizer that the function will return twice.
+/// This prevents wrong optimizations which can cause bugs.
+///
+#define RETURNS_TWICE  __attribute__((returns_twice))
   #else
-    ///
-    /// Tell the code optimizer that the function will return twice.
-    /// This prevents wrong optimizations which can cause bugs.
-    ///
-    #define RETURNS_TWICE
+///
+/// Tell the code optimizer that the function will return twice.
+/// This prevents wrong optimizations which can cause bugs.
+///
+#define RETURNS_TWICE
   #endif
 #endif
 
@@ -186,58 +185,50 @@ SPDX-License-Identifier: BSD-2-Clause-Patent
 ///
 /// Private worker functions for ASM_PFX()
 ///
-#define _CONCATENATE(a, b)  __CONCATENATE(a, b)
-#define __CONCATENATE(a, b) a ## b
+#define _CONCATENATE(a, b)   __CONCATENATE(a, b)
+#define __CONCATENATE(a, b)  a ## b
 
 ///
 /// The __USER_LABEL_PREFIX__ macro predefined by GNUC represents the prefix
 /// on symbols in assembly language.
 ///
-#define ASM_PFX(name) _CONCATENATE (__USER_LABEL_PREFIX__, name)
+#define ASM_PFX(name)  _CONCATENATE (__USER_LABEL_PREFIX__, name)
 
 #ifdef __APPLE__
-  //
-  // Apple extension that is used by the linker to optimize code size
-  // with assembly functions. Put at the end of your .S files
-  //
-  #define ASM_FUNCTION_REMOVE_IF_UNREFERENCED  .subsections_via_symbols
+//
+// Apple extension that is used by the linker to optimize code size
+// with assembly functions. Put at the end of your .S files
+//
+#define ASM_FUNCTION_REMOVE_IF_UNREFERENCED  .subsections_via_symbols
 #else
-  #define ASM_FUNCTION_REMOVE_IF_UNREFERENCED
+#define ASM_FUNCTION_REMOVE_IF_UNREFERENCED
 #endif
 
-#ifdef __CC_ARM
-  //
-  // Older RVCT ARM compilers don't fully support #pragma pack and require __packed
-  // as a prefix for the structure.
-  //
-  #define PACKED  __packed
-#else
-  #define PACKED
-#endif
+#define PACKED
 
 ///
 /// 128 bit buffer containing a unique identifier value.
 /// Unless otherwise specified, aligned on a 64 bit boundary.
 ///
 typedef struct {
-  UINT32  Data1;
-  UINT16  Data2;
-  UINT16  Data3;
-  UINT8   Data4[8];
+  UINT32    Data1;
+  UINT16    Data2;
+  UINT16    Data3;
+  UINT8     Data4[8];
 } GUID;
 
 ///
 /// 4-byte buffer. An IPv4 internet protocol address.
 ///
 typedef struct {
-  UINT8 Addr[4];
+  UINT8    Addr[4];
 } IPv4_ADDRESS;
 
 ///
 /// 16-byte buffer. An IPv6 internet protocol address.
 ///
 typedef struct {
-  UINT8 Addr[16];
+  UINT8    Addr[16];
 } IPv6_ADDRESS;
 
 //
@@ -254,8 +245,8 @@ typedef struct _LIST_ENTRY LIST_ENTRY;
 /// _LIST_ENTRY structure definition.
 ///
 struct _LIST_ENTRY {
-  LIST_ENTRY  *ForwardLink;
-  LIST_ENTRY  *BackLink;
+  LIST_ENTRY    *ForwardLink;
+  LIST_ENTRY    *BackLink;
 };
 
 //
@@ -265,17 +256,17 @@ struct _LIST_ENTRY {
 ///
 /// Datum is read-only.
 ///
-#define CONST     const
+#define CONST  const
 
 ///
 /// Datum is scoped to the current file or function.
 ///
-#define STATIC    static
+#define STATIC  static
 
 ///
 /// Undeclared type.
 ///
-#define VOID      void
+#define VOID  void
 
 //
 // Modifiers for Data Types used to self document code.
@@ -313,7 +304,7 @@ struct _LIST_ENTRY {
 /// Boolean false value.  UEFI Specification defines this value to be 0,
 /// but this form is more portable.
 ///
-#define FALSE ((BOOLEAN)(0==1))
+#define FALSE  ((BOOLEAN)(0==1))
 
 ///
 /// NULL pointer (VOID *)
@@ -327,7 +318,7 @@ struct _LIST_ENTRY {
 //
 // Null character
 //
-#define CHAR_NULL             0x0000
+#define CHAR_NULL  0x0000
 
 ///
 /// Maximum values for common UEFI Data Types
@@ -349,70 +340,70 @@ struct _LIST_ENTRY {
 #define MIN_INT32  (((INT32) -2147483647) - 1)
 #define MIN_INT64  (((INT64) -9223372036854775807LL) - 1)
 
-#define  BIT0     0x00000001
-#define  BIT1     0x00000002
-#define  BIT2     0x00000004
-#define  BIT3     0x00000008
-#define  BIT4     0x00000010
-#define  BIT5     0x00000020
-#define  BIT6     0x00000040
-#define  BIT7     0x00000080
-#define  BIT8     0x00000100
-#define  BIT9     0x00000200
-#define  BIT10    0x00000400
-#define  BIT11    0x00000800
-#define  BIT12    0x00001000
-#define  BIT13    0x00002000
-#define  BIT14    0x00004000
-#define  BIT15    0x00008000
-#define  BIT16    0x00010000
-#define  BIT17    0x00020000
-#define  BIT18    0x00040000
-#define  BIT19    0x00080000
-#define  BIT20    0x00100000
-#define  BIT21    0x00200000
-#define  BIT22    0x00400000
-#define  BIT23    0x00800000
-#define  BIT24    0x01000000
-#define  BIT25    0x02000000
-#define  BIT26    0x04000000
-#define  BIT27    0x08000000
-#define  BIT28    0x10000000
-#define  BIT29    0x20000000
-#define  BIT30    0x40000000
-#define  BIT31    0x80000000
-#define  BIT32    0x0000000100000000ULL
-#define  BIT33    0x0000000200000000ULL
-#define  BIT34    0x0000000400000000ULL
-#define  BIT35    0x0000000800000000ULL
-#define  BIT36    0x0000001000000000ULL
-#define  BIT37    0x0000002000000000ULL
-#define  BIT38    0x0000004000000000ULL
-#define  BIT39    0x0000008000000000ULL
-#define  BIT40    0x0000010000000000ULL
-#define  BIT41    0x0000020000000000ULL
-#define  BIT42    0x0000040000000000ULL
-#define  BIT43    0x0000080000000000ULL
-#define  BIT44    0x0000100000000000ULL
-#define  BIT45    0x0000200000000000ULL
-#define  BIT46    0x0000400000000000ULL
-#define  BIT47    0x0000800000000000ULL
-#define  BIT48    0x0001000000000000ULL
-#define  BIT49    0x0002000000000000ULL
-#define  BIT50    0x0004000000000000ULL
-#define  BIT51    0x0008000000000000ULL
-#define  BIT52    0x0010000000000000ULL
-#define  BIT53    0x0020000000000000ULL
-#define  BIT54    0x0040000000000000ULL
-#define  BIT55    0x0080000000000000ULL
-#define  BIT56    0x0100000000000000ULL
-#define  BIT57    0x0200000000000000ULL
-#define  BIT58    0x0400000000000000ULL
-#define  BIT59    0x0800000000000000ULL
-#define  BIT60    0x1000000000000000ULL
-#define  BIT61    0x2000000000000000ULL
-#define  BIT62    0x4000000000000000ULL
-#define  BIT63    0x8000000000000000ULL
+#define  BIT0   0x00000001
+#define  BIT1   0x00000002
+#define  BIT2   0x00000004
+#define  BIT3   0x00000008
+#define  BIT4   0x00000010
+#define  BIT5   0x00000020
+#define  BIT6   0x00000040
+#define  BIT7   0x00000080
+#define  BIT8   0x00000100
+#define  BIT9   0x00000200
+#define  BIT10  0x00000400
+#define  BIT11  0x00000800
+#define  BIT12  0x00001000
+#define  BIT13  0x00002000
+#define  BIT14  0x00004000
+#define  BIT15  0x00008000
+#define  BIT16  0x00010000
+#define  BIT17  0x00020000
+#define  BIT18  0x00040000
+#define  BIT19  0x00080000
+#define  BIT20  0x00100000
+#define  BIT21  0x00200000
+#define  BIT22  0x00400000
+#define  BIT23  0x00800000
+#define  BIT24  0x01000000
+#define  BIT25  0x02000000
+#define  BIT26  0x04000000
+#define  BIT27  0x08000000
+#define  BIT28  0x10000000
+#define  BIT29  0x20000000
+#define  BIT30  0x40000000
+#define  BIT31  0x80000000
+#define  BIT32  0x0000000100000000ULL
+#define  BIT33  0x0000000200000000ULL
+#define  BIT34  0x0000000400000000ULL
+#define  BIT35  0x0000000800000000ULL
+#define  BIT36  0x0000001000000000ULL
+#define  BIT37  0x0000002000000000ULL
+#define  BIT38  0x0000004000000000ULL
+#define  BIT39  0x0000008000000000ULL
+#define  BIT40  0x0000010000000000ULL
+#define  BIT41  0x0000020000000000ULL
+#define  BIT42  0x0000040000000000ULL
+#define  BIT43  0x0000080000000000ULL
+#define  BIT44  0x0000100000000000ULL
+#define  BIT45  0x0000200000000000ULL
+#define  BIT46  0x0000400000000000ULL
+#define  BIT47  0x0000800000000000ULL
+#define  BIT48  0x0001000000000000ULL
+#define  BIT49  0x0002000000000000ULL
+#define  BIT50  0x0004000000000000ULL
+#define  BIT51  0x0008000000000000ULL
+#define  BIT52  0x0010000000000000ULL
+#define  BIT53  0x0020000000000000ULL
+#define  BIT54  0x0040000000000000ULL
+#define  BIT55  0x0080000000000000ULL
+#define  BIT56  0x0100000000000000ULL
+#define  BIT57  0x0200000000000000ULL
+#define  BIT58  0x0400000000000000ULL
+#define  BIT59  0x0800000000000000ULL
+#define  BIT60  0x1000000000000000ULL
+#define  BIT61  0x2000000000000000ULL
+#define  BIT62  0x4000000000000000ULL
+#define  BIT63  0x8000000000000000ULL
 
 #define  SIZE_1KB    0x00000400
 #define  SIZE_2KB    0x00000800
@@ -581,53 +572,23 @@ struct _LIST_ENTRY {
 
   @return The aligned size.
 **/
-#define _INT_SIZE_OF(n) ((sizeof (n) + sizeof (UINTN) - 1) &~(sizeof (UINTN) - 1))
+#define _INT_SIZE_OF(n)  ((sizeof (n) + sizeof (UINTN) - 1) &~(sizeof (UINTN) - 1))
 
-#if defined(__CC_ARM)
-//
-// RVCT ARM variable argument list support.
-//
-
-///
-/// Variable used to traverse the list of arguments. This type can vary by
-/// implementation and could be an array or structure.
-///
-#ifdef __APCS_ADSABI
-  typedef int         *va_list[1];
-  #define VA_LIST     va_list
-#else
-  typedef struct __va_list { void *__ap; } va_list;
-  #define VA_LIST                          va_list
-#endif
-
-#define VA_START(Marker, Parameter)   __va_start(Marker, Parameter)
-
-#define VA_ARG(Marker, TYPE)          __va_arg(Marker, TYPE)
-
-#define VA_END(Marker)                ((void)0)
-
-// For some ARM RVCT compilers, __va_copy is not defined
-#ifndef __va_copy
-  #define __va_copy(dest, src) ((void)((dest) = (src)))
-#endif
-
-#define VA_COPY(Dest, Start)          __va_copy (Dest, Start)
-
-#elif defined(_M_ARM) || defined(_M_ARM64)
+#if defined (_M_ARM) || defined (_M_ARM64)
 //
 // MSFT ARM variable argument list support.
 //
 
-typedef char* VA_LIST;
+typedef char *VA_LIST;
 
-#define VA_START(Marker, Parameter)     __va_start (&Marker, &Parameter, _INT_SIZE_OF (Parameter), __alignof(Parameter), &Parameter)
-#define VA_ARG(Marker, TYPE)            (*(TYPE *) ((Marker += _INT_SIZE_OF (TYPE) + ((-(INTN)Marker) & (sizeof(TYPE) - 1))) - _INT_SIZE_OF (TYPE)))
-#define VA_END(Marker)                  (Marker = (VA_LIST) 0)
-#define VA_COPY(Dest, Start)            ((void)((Dest) = (Start)))
+#define VA_START(Marker, Parameter)  __va_start (&Marker, &Parameter, _INT_SIZE_OF (Parameter), __alignof(Parameter), &Parameter)
+#define VA_ARG(Marker, TYPE)         (*(TYPE *) ((Marker += _INT_SIZE_OF (TYPE) + ((-(INTN)Marker) & (sizeof(TYPE) - 1))) - _INT_SIZE_OF (TYPE)))
+#define VA_END(Marker)               (Marker = (VA_LIST) 0)
+#define VA_COPY(Dest, Start)         ((void)((Dest) = (Start)))
 
-#elif defined(__GNUC__) || defined(__clang__)
+#elif defined (__GNUC__) || defined (__clang__)
 
-#if defined(MDE_CPU_X64) && !defined(NO_MSABI_VA_FUNCS)
+  #if defined (MDE_CPU_X64) && !defined (NO_MSABI_VA_FUNCS)
 //
 // X64 only. Use MS ABI version of GCC built-in macros for variable argument lists.
 //
@@ -643,13 +604,13 @@ typedef __builtin_ms_va_list VA_LIST;
 
 #define VA_START(Marker, Parameter)  __builtin_ms_va_start (Marker, Parameter)
 
-#define VA_ARG(Marker, TYPE)         ((sizeof (TYPE) < sizeof (UINTN)) ? (TYPE)(__builtin_va_arg (Marker, UINTN)) : (TYPE)(__builtin_va_arg (Marker, TYPE)))
+#define VA_ARG(Marker, TYPE)  ((sizeof (TYPE) < sizeof (UINTN)) ? (TYPE)(__builtin_va_arg (Marker, UINTN)) : (TYPE)(__builtin_va_arg (Marker, TYPE)))
 
-#define VA_END(Marker)               __builtin_ms_va_end (Marker)
+#define VA_END(Marker)  __builtin_ms_va_end (Marker)
 
-#define VA_COPY(Dest, Start)         __builtin_ms_va_copy (Dest, Start)
+#define VA_COPY(Dest, Start)  __builtin_ms_va_copy (Dest, Start)
 
-#else
+  #else
 //
 // Use GCC built-in macros for variable argument lists.
 //
@@ -662,13 +623,13 @@ typedef __builtin_va_list VA_LIST;
 
 #define VA_START(Marker, Parameter)  __builtin_va_start (Marker, Parameter)
 
-#define VA_ARG(Marker, TYPE)         ((sizeof (TYPE) < sizeof (UINTN)) ? (TYPE)(__builtin_va_arg (Marker, UINTN)) : (TYPE)(__builtin_va_arg (Marker, TYPE)))
+#define VA_ARG(Marker, TYPE)  ((sizeof (TYPE) < sizeof (UINTN)) ? (TYPE)(__builtin_va_arg (Marker, UINTN)) : (TYPE)(__builtin_va_arg (Marker, TYPE)))
 
-#define VA_END(Marker)               __builtin_va_end (Marker)
+#define VA_END(Marker)  __builtin_va_end (Marker)
 
-#define VA_COPY(Dest, Start)         __builtin_va_copy (Dest, Start)
+#define VA_COPY(Dest, Start)  __builtin_va_copy (Dest, Start)
 
-#endif
+  #endif
 
 #else
 ///
@@ -693,7 +654,7 @@ typedef CHAR8 *VA_LIST;
   @return  A pointer to the beginning of a variable argument list.
 
 **/
-#define VA_START(Marker, Parameter) (Marker = (VA_LIST) ((UINTN) & (Parameter) + _INT_SIZE_OF (Parameter)))
+#define VA_START(Marker, Parameter)  (Marker = (VA_LIST) ((UINTN) & (Parameter) + _INT_SIZE_OF (Parameter)))
 
 /**
   Returns an argument of a specified type from a variable argument list and updates
@@ -711,7 +672,7 @@ typedef CHAR8 *VA_LIST;
   @return  An argument of the type specified by TYPE.
 
 **/
-#define VA_ARG(Marker, TYPE)   (*(TYPE *) ((Marker += _INT_SIZE_OF (TYPE)) - _INT_SIZE_OF (TYPE)))
+#define VA_ARG(Marker, TYPE)  (*(TYPE *) ((Marker += _INT_SIZE_OF (TYPE)) - _INT_SIZE_OF (TYPE)))
 
 /**
   Terminates the use of a variable argument list.
@@ -723,7 +684,7 @@ typedef CHAR8 *VA_LIST;
   @param   Marker   VA_LIST used to traverse the list of arguments.
 
 **/
-#define VA_END(Marker)      (Marker = (VA_LIST) 0)
+#define VA_END(Marker)  (Marker = (VA_LIST) 0)
 
 /**
   Initializes a VA_LIST as a copy of an existing VA_LIST.
@@ -743,7 +704,7 @@ typedef CHAR8 *VA_LIST;
 ///
 /// Pointer to the start of a variable argument list stored in a memory buffer. Same as UINT8 *.
 ///
-typedef UINTN  *BASE_LIST;
+typedef UINTN *BASE_LIST;
 
 /**
   Returns the size of a data type in sizeof(UINTN) units rounded up to the nearest UINTN boundary.
@@ -752,7 +713,7 @@ typedef UINTN  *BASE_LIST;
 
   @return The size of TYPE in sizeof (UINTN) units rounded up to the nearest UINTN boundary.
 **/
-#define _BASE_INT_SIZE_OF(TYPE) ((sizeof (TYPE) + sizeof (UINTN) - 1) / sizeof (UINTN))
+#define _BASE_INT_SIZE_OF(TYPE)  ((sizeof (TYPE) + sizeof (UINTN) - 1) / sizeof (UINTN))
 
 /**
   Returns an argument of a specified type from a variable argument list and updates
@@ -770,7 +731,7 @@ typedef UINTN  *BASE_LIST;
   @return  An argument of the type specified by TYPE.
 
 **/
-#define BASE_ARG(Marker, TYPE)   (*(TYPE *) ((Marker += _BASE_INT_SIZE_OF (TYPE)) - _BASE_INT_SIZE_OF (TYPE)))
+#define BASE_ARG(Marker, TYPE)  (*(TYPE *) ((Marker += _BASE_INT_SIZE_OF (TYPE)) - _BASE_INT_SIZE_OF (TYPE)))
 
 /**
   The macro that returns the byte offset of a field in a data structure.
@@ -785,12 +746,12 @@ typedef UINTN  *BASE_LIST;
   @return  Offset, in bytes, of field.
 
 **/
-#if (defined(__GNUC__) && __GNUC__ >= 4) || defined(__clang__)
-#define OFFSET_OF(TYPE, Field) ((UINTN) __builtin_offsetof(TYPE, Field))
+#if (defined (__GNUC__) && __GNUC__ >= 4) || defined (__clang__)
+#define OFFSET_OF(TYPE, Field)  ((UINTN) __builtin_offsetof(TYPE, Field))
 #endif
 
 #ifndef OFFSET_OF
-#define OFFSET_OF(TYPE, Field) ((UINTN) &(((TYPE *)0)->Field))
+#define OFFSET_OF(TYPE, Field)  ((UINTN) &(((TYPE *)0)->Field))
 #endif
 
 /**
@@ -802,11 +763,11 @@ typedef UINTN  *BASE_LIST;
 
 **/
 #ifdef MDE_CPU_EBC
-  #define STATIC_ASSERT(Expression, Message)
-#elif defined(_MSC_EXTENSIONS)
-  #define STATIC_ASSERT static_assert
+#define STATIC_ASSERT(Expression, Message)
+#elif defined (_MSC_EXTENSIONS)
+#define STATIC_ASSERT  static_assert
 #else
-  #define STATIC_ASSERT _Static_assert
+#define STATIC_ASSERT  _Static_assert
 #endif
 
 //
@@ -892,7 +853,7 @@ STATIC_ASSERT (sizeof (__VERIFY_UINT32_ENUM_SIZE) == 4, "Size of enum does not m
   @return  A value up to the next boundary.
 
 **/
-#define ALIGN_VALUE(Value, Alignment) ((Value) + (((Alignment) - (Value)) & ((Alignment) - 1)))
+#define ALIGN_VALUE(Value, Alignment)  ((Value) + (((Alignment) - (Value)) & ((Alignment) - 1)))
 
 /**
   Adjust a pointer by adding the minimum offset required for it to be aligned on
@@ -907,7 +868,7 @@ STATIC_ASSERT (sizeof (__VERIFY_UINT32_ENUM_SIZE) == 4, "Size of enum does not m
   @return  Pointer to the aligned address.
 
 **/
-#define ALIGN_POINTER(Pointer, Alignment) ((VOID *) (ALIGN_VALUE ((UINTN)(Pointer), (Alignment))))
+#define ALIGN_POINTER(Pointer, Alignment)  ((VOID *) (ALIGN_VALUE ((UINTN)(Pointer), (Alignment))))
 
 /**
   Rounds a value up to the next natural boundary for the current CPU.
@@ -923,7 +884,6 @@ STATIC_ASSERT (sizeof (__VERIFY_UINT32_ENUM_SIZE) == 4, "Size of enum does not m
 **/
 #define ALIGN_VARIABLE(Value)  ALIGN_VALUE ((Value), sizeof (UINTN))
 
-
 /**
   Return the maximum of two operands.
 
@@ -982,7 +942,7 @@ typedef UINTN RETURN_STATUS;
   @return The value specified by StatusCode with the highest bit set.
 
 **/
-#define ENCODE_ERROR(StatusCode)     ((RETURN_STATUS)(MAX_BIT | (StatusCode)))
+#define ENCODE_ERROR(StatusCode)  ((RETURN_STATUS)(MAX_BIT | (StatusCode)))
 
 /**
   Produces a RETURN_STATUS code with the highest bit clear.
@@ -993,7 +953,7 @@ typedef UINTN RETURN_STATUS;
   @return The value specified by StatusCode with the highest bit clear.
 
 **/
-#define ENCODE_WARNING(StatusCode)   ((RETURN_STATUS)(StatusCode))
+#define ENCODE_WARNING(StatusCode)  ((RETURN_STATUS)(StatusCode))
 
 /**
   Returns TRUE if a specified RETURN_STATUS code is an error code.
@@ -1006,138 +966,138 @@ typedef UINTN RETURN_STATUS;
   @retval FALSE         The high bit of StatusCode is clear.
 
 **/
-#define RETURN_ERROR(StatusCode)     (((INTN)(RETURN_STATUS)(StatusCode)) < 0)
+#define RETURN_ERROR(StatusCode)  (((INTN)(RETURN_STATUS)(StatusCode)) < 0)
 
 ///
 /// The operation completed successfully.
 ///
-#define RETURN_SUCCESS               0
+#define RETURN_SUCCESS  0
 
 ///
 /// The image failed to load.
 ///
-#define RETURN_LOAD_ERROR            ENCODE_ERROR (1)
+#define RETURN_LOAD_ERROR  ENCODE_ERROR (1)
 
 ///
 /// The parameter was incorrect.
 ///
-#define RETURN_INVALID_PARAMETER     ENCODE_ERROR (2)
+#define RETURN_INVALID_PARAMETER  ENCODE_ERROR (2)
 
 ///
 /// The operation is not supported.
 ///
-#define RETURN_UNSUPPORTED           ENCODE_ERROR (3)
+#define RETURN_UNSUPPORTED  ENCODE_ERROR (3)
 
 ///
 /// The buffer was not the proper size for the request.
 ///
-#define RETURN_BAD_BUFFER_SIZE       ENCODE_ERROR (4)
+#define RETURN_BAD_BUFFER_SIZE  ENCODE_ERROR (4)
 
 ///
 /// The buffer was not large enough to hold the requested data.
 /// The required buffer size is returned in the appropriate
 /// parameter when this error occurs.
 ///
-#define RETURN_BUFFER_TOO_SMALL      ENCODE_ERROR (5)
+#define RETURN_BUFFER_TOO_SMALL  ENCODE_ERROR (5)
 
 ///
 /// There is no data pending upon return.
 ///
-#define RETURN_NOT_READY             ENCODE_ERROR (6)
+#define RETURN_NOT_READY  ENCODE_ERROR (6)
 
 ///
 /// The physical device reported an error while attempting the
 /// operation.
 ///
-#define RETURN_DEVICE_ERROR          ENCODE_ERROR (7)
+#define RETURN_DEVICE_ERROR  ENCODE_ERROR (7)
 
 ///
 /// The device can not be written to.
 ///
-#define RETURN_WRITE_PROTECTED       ENCODE_ERROR (8)
+#define RETURN_WRITE_PROTECTED  ENCODE_ERROR (8)
 
 ///
 /// The resource has run out.
 ///
-#define RETURN_OUT_OF_RESOURCES      ENCODE_ERROR (9)
+#define RETURN_OUT_OF_RESOURCES  ENCODE_ERROR (9)
 
 ///
 /// An inconsistency was detected on the file system causing the
 /// operation to fail.
 ///
-#define RETURN_VOLUME_CORRUPTED      ENCODE_ERROR (10)
+#define RETURN_VOLUME_CORRUPTED  ENCODE_ERROR (10)
 
 ///
 /// There is no more space on the file system.
 ///
-#define RETURN_VOLUME_FULL           ENCODE_ERROR (11)
+#define RETURN_VOLUME_FULL  ENCODE_ERROR (11)
 
 ///
 /// The device does not contain any medium to perform the
 /// operation.
 ///
-#define RETURN_NO_MEDIA              ENCODE_ERROR (12)
+#define RETURN_NO_MEDIA  ENCODE_ERROR (12)
 
 ///
 /// The medium in the device has changed since the last
 /// access.
 ///
-#define RETURN_MEDIA_CHANGED         ENCODE_ERROR (13)
+#define RETURN_MEDIA_CHANGED  ENCODE_ERROR (13)
 
 ///
 /// The item was not found.
 ///
-#define RETURN_NOT_FOUND             ENCODE_ERROR (14)
+#define RETURN_NOT_FOUND  ENCODE_ERROR (14)
 
 ///
 /// Access was denied.
 ///
-#define RETURN_ACCESS_DENIED         ENCODE_ERROR (15)
+#define RETURN_ACCESS_DENIED  ENCODE_ERROR (15)
 
 ///
 /// The server was not found or did not respond to the request.
 ///
-#define RETURN_NO_RESPONSE           ENCODE_ERROR (16)
+#define RETURN_NO_RESPONSE  ENCODE_ERROR (16)
 
 ///
 /// A mapping to the device does not exist.
 ///
-#define RETURN_NO_MAPPING            ENCODE_ERROR (17)
+#define RETURN_NO_MAPPING  ENCODE_ERROR (17)
 
 ///
 /// A timeout time expired.
 ///
-#define RETURN_TIMEOUT               ENCODE_ERROR (18)
+#define RETURN_TIMEOUT  ENCODE_ERROR (18)
 
 ///
 /// The protocol has not been started.
 ///
-#define RETURN_NOT_STARTED           ENCODE_ERROR (19)
+#define RETURN_NOT_STARTED  ENCODE_ERROR (19)
 
 ///
 /// The protocol has already been started.
 ///
-#define RETURN_ALREADY_STARTED       ENCODE_ERROR (20)
+#define RETURN_ALREADY_STARTED  ENCODE_ERROR (20)
 
 ///
 /// The operation was aborted.
 ///
-#define RETURN_ABORTED               ENCODE_ERROR (21)
+#define RETURN_ABORTED  ENCODE_ERROR (21)
 
 ///
 /// An ICMP error occurred during the network operation.
 ///
-#define RETURN_ICMP_ERROR            ENCODE_ERROR (22)
+#define RETURN_ICMP_ERROR  ENCODE_ERROR (22)
 
 ///
 /// A TFTP error occurred during the network operation.
 ///
-#define RETURN_TFTP_ERROR            ENCODE_ERROR (23)
+#define RETURN_TFTP_ERROR  ENCODE_ERROR (23)
 
 ///
 /// A protocol error occurred during the network operation.
 ///
-#define RETURN_PROTOCOL_ERROR        ENCODE_ERROR (24)
+#define RETURN_PROTOCOL_ERROR  ENCODE_ERROR (24)
 
 ///
 /// A function encountered an internal version that was
@@ -1148,74 +1108,73 @@ typedef UINTN RETURN_STATUS;
 ///
 /// The function was not performed due to a security violation.
 ///
-#define RETURN_SECURITY_VIOLATION    ENCODE_ERROR (26)
+#define RETURN_SECURITY_VIOLATION  ENCODE_ERROR (26)
 
 ///
 /// A CRC error was detected.
 ///
-#define RETURN_CRC_ERROR             ENCODE_ERROR (27)
+#define RETURN_CRC_ERROR  ENCODE_ERROR (27)
 
 ///
 /// The beginning or end of media was reached.
 ///
-#define RETURN_END_OF_MEDIA          ENCODE_ERROR (28)
+#define RETURN_END_OF_MEDIA  ENCODE_ERROR (28)
 
 ///
 /// The end of the file was reached.
 ///
-#define RETURN_END_OF_FILE           ENCODE_ERROR (31)
+#define RETURN_END_OF_FILE  ENCODE_ERROR (31)
 
 ///
 /// The language specified was invalid.
 ///
-#define RETURN_INVALID_LANGUAGE      ENCODE_ERROR (32)
+#define RETURN_INVALID_LANGUAGE  ENCODE_ERROR (32)
 
 ///
 /// The security status of the data is unknown or compromised
 /// and the data must be updated or replaced to restore a valid
 /// security status.
 ///
-#define RETURN_COMPROMISED_DATA      ENCODE_ERROR (33)
+#define RETURN_COMPROMISED_DATA  ENCODE_ERROR (33)
 
 ///
 /// A HTTP error occurred during the network operation.
 ///
-#define RETURN_HTTP_ERROR            ENCODE_ERROR (35)
+#define RETURN_HTTP_ERROR  ENCODE_ERROR (35)
 
 ///
 /// The string contained one or more characters that
 /// the device could not render and were skipped.
 ///
-#define RETURN_WARN_UNKNOWN_GLYPH    ENCODE_WARNING (1)
+#define RETURN_WARN_UNKNOWN_GLYPH  ENCODE_WARNING (1)
 
 ///
 /// The handle was closed, but the file was not deleted.
 ///
-#define RETURN_WARN_DELETE_FAILURE   ENCODE_WARNING (2)
+#define RETURN_WARN_DELETE_FAILURE  ENCODE_WARNING (2)
 
 ///
 /// The handle was closed, but the data to the file was not
 /// flushed properly.
 ///
-#define RETURN_WARN_WRITE_FAILURE    ENCODE_WARNING (3)
+#define RETURN_WARN_WRITE_FAILURE  ENCODE_WARNING (3)
 
 ///
 /// The resulting buffer was too small, and the data was
 /// truncated to the buffer size.
 ///
-#define RETURN_WARN_BUFFER_TOO_SMALL ENCODE_WARNING (4)
+#define RETURN_WARN_BUFFER_TOO_SMALL  ENCODE_WARNING (4)
 
 ///
 /// The data has not been updated within the timeframe set by
 /// local policy for this type of data.
 ///
-#define RETURN_WARN_STALE_DATA       ENCODE_WARNING (5)
+#define RETURN_WARN_STALE_DATA  ENCODE_WARNING (5)
 
 ///
 /// The resulting buffer contains UEFI-compliant file system.
 ///
-#define RETURN_WARN_FILE_SYSTEM      ENCODE_WARNING (6)
-
+#define RETURN_WARN_FILE_SYSTEM  ENCODE_WARNING (6)
 
 /**
   Returns a 16-bit signature built from 2 ASCII characters.
@@ -1229,7 +1188,7 @@ typedef UINTN RETURN_STATUS;
   @return A 16-bit value built from the two ASCII characters specified by A and B.
 
 **/
-#define SIGNATURE_16(A, B)        ((A) | (B << 8))
+#define SIGNATURE_16(A, B)  ((A) | (B << 8))
 
 /**
   Returns a 32-bit signature built from 4 ASCII characters.
@@ -1270,45 +1229,52 @@ typedef UINTN RETURN_STATUS;
 #define SIGNATURE_64(A, B, C, D, E, F, G, H) \
     (SIGNATURE_32 (A, B, C, D) | ((UINT64) (SIGNATURE_32 (E, F, G, H)) << 32))
 
-#if defined(_MSC_EXTENSIONS) && !defined (__INTEL_COMPILER) && !defined (MDE_CPU_EBC)
-  void * _ReturnAddress(void);
+#if defined (_MSC_EXTENSIONS) && !defined (__INTEL_COMPILER) && !defined (MDE_CPU_EBC)
+void *
+_ReturnAddress (
+  void
+  );
+
   #pragma intrinsic(_ReturnAddress)
-  /**
-    Get the return address of the calling function.
 
-    Based on intrinsic function _ReturnAddress that provides the address of
-    the instruction in the calling function that will be executed after
-    control returns to the caller.
+/**
+  Get the return address of the calling function.
 
-    @param L    Return Level.
+  Based on intrinsic function _ReturnAddress that provides the address of
+  the instruction in the calling function that will be executed after
+  control returns to the caller.
 
-    @return The return address of the calling function or 0 if L != 0.
+  @param L    Return Level.
 
-  **/
-  #define RETURN_ADDRESS(L)     ((L == 0) ? _ReturnAddress() : (VOID *) 0)
+  @return The return address of the calling function or 0 if L != 0.
+
+**/
+#define RETURN_ADDRESS(L)  ((L == 0) ? _ReturnAddress() : (VOID *) 0)
 #elif defined (__GNUC__) || defined (__clang__)
-  /**
-    Get the return address of the calling function.
 
-    Based on built-in Function __builtin_return_address that returns
-    the return address of the current function, or of one of its callers.
+/**
+  Get the return address of the calling function.
 
-    @param L    Return Level.
+  Based on built-in Function __builtin_return_address that returns
+  the return address of the current function, or of one of its callers.
 
-    @return The return address of the calling function.
+  @param L    Return Level.
 
-  **/
-  #define RETURN_ADDRESS(L)     __builtin_return_address (L)
+  @return The return address of the calling function.
+
+**/
+#define RETURN_ADDRESS(L)  __builtin_return_address (L)
 #else
-  /**
-    Get the return address of the calling function.
 
-    @param L    Return Level.
+/**
+  Get the return address of the calling function.
 
-    @return 0 as compilers don't support this feature.
+  @param L    Return Level.
 
-  **/
-  #define RETURN_ADDRESS(L)     ((VOID *) 0)
+  @return 0 as compilers don't support this feature.
+
+**/
+#define RETURN_ADDRESS(L)  ((VOID *) 0)
 #endif
 
 /**
@@ -1322,7 +1288,6 @@ typedef UINTN RETURN_STATUS;
   @return The number of elements in Array. The result has type UINTN.
 
 **/
-#define ARRAY_SIZE(Array) (sizeof (Array) / sizeof ((Array)[0]))
+#define ARRAY_SIZE(Array)  (sizeof (Array) / sizeof ((Array)[0]))
 
 #endif
-
